﻿Anritsu                                                     MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XC DC Pulse Cal /N5531S
DATE:                  2014-02-22 14:53:51
AUTHOR:                Al Shannon
REVISION:              $Revision: 8094 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       148
CONFIGURATION:         Agilent PSA (233)
CONFIGURATION:         Agilent EPM
=============================================================================
#
#  Text Source:
#    $RCSfile: sub_mg369xc_dcpulsecal_n5531s.mc $
#    $Date: 2014-06-10 06:38:31 -0700 (Tue, 10 Jun 2014) $
#
#  Procedure Author:
#        AWS
#
#  Model(s) Covered:
#        MG369XC
#
#  Compatibility:
#        MET/CAL 8.0 or later
#
#  Subprocedures:
#        Sub MG369XC Init Cal Correction File
#        Sub MG369XC Get Flat Cal Power
#        Sub MG369XC Level Adj Connection /N5531S
#        Sub MG369XC Settling Delay
#        Sub Get Offset Value
#        Sub MG369XC Get Flatness Table Index
#        Sub MG369XC Store DC Pulse Corrections
#
#
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Anritsu Company.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  HEAD         {Down Converter Pulse Calibration}
  1.002  HEAD         -2

# Prepare the temporary correction file
  1.003  CALL         Sub MG369XC Init Cal Correction File

  1.004  MATH         startFreqGHz = 1
  1.005  MATH         stepFreqGHz = 0.1

  1.006  IF           @Opt_4
  1.007  MATH         stopFreqGHz = 2.2
  1.008  ELSE
  1.009  MATH         stopFreqGHz = 1.999
  1.010  ENDIF

# Set step 0 to determine the power output from the DUT
  1.011  MATH         @Step = 0
  1.012  MATH         @FreqGHz = startFreqGHz

# Set power level based on step, firmware version & rated power
  1.013  CALL         Sub MG369XC Get Flat Cal Power
  1.014  MATH         @LvldBm = @FlatCalLvldBm

# Set the switch freq so that only one power sensor is neeed.
# No attenuator is used in this test.
  1.015  MATH         @N5532_PS_Switch_Freq = startFreqGHz
  1.016  MATH         @ConnPadValue = 0
  1.017  CALL         Sub MG369XC Level Adj Connection /N5531S

# Set up the N5531S for RF Power measurements
  1.018  N5531        RefFreqOutput = 10 MHz
  1.018  N5531        Freq = [V startFreqGHz]GHz; SensorModule = Same
  1.018  N5531        +Power = [V @LvldBm]dBm; Setup

# Prepare the signal generator for DC Pulse calibration which is run
# in flattness calibration mode 128.
  1.019  IEEE         RST[D2000]RF0
  1.020  IEEE         CSB SQ1 MB2D SB1 WH1[D2000]
  1.021  IEEE         WHF128[D50]

# Set step 20 for DC Pulse Cal
  1.022  IEEE         ATT20[D50]

  1.023  WHILE        @FreqGHz <= stopFreqGHz

  1.024  TARGET       -p

  1.025  CALL         Sub MG369XC Level Adj Connection /N5531S

  1.026  MATH         S[1] = FMT(@FreqGHz,"%5.2f")
  1.027  HEAD         -2[S1] GHz

  1.028  MATH         freqMHz = @FreqGHz * 1000
  1.029  IEEE         FRQ[V freqMHz]x[D50]

# Let the hardware settle after setting the frequency
  1.030  CALL         Sub MG369XC Settling Delay

  1.031  IEEE2        [@N5531S]:sens:freq:cent [V @FreqGHz] ghz
  1.032  N5531        RefFreqOutput = 10 MHz
  1.032  N5531        Freq = [V @FreqGHz]GHz; SensorModule = Same
  1.032  N5531        +Power = [V @LvldBm]dBm; Read

# Determine the amount the adapters and pads affect the power measurement
  1.033  MATH         @Offset_FreqGHz = @FreqGHz
  1.034  CALL         Sub Get Offset Value
  1.035  MATH         MEM = MEM + @Offset_Value

# Calculate the correction
  1.036  MATH         Correction = RND((MEM - @LvldBm) * 100 )

# Save the correction in the temporary file
  1.037  CALL         Sub MG369XC Get Flatness Table Index
  1.038  MATH         s[1] = @Step & "," & @TableIndex
  1.039  MATH         s[2] = "," & @FreqGHz & "," & Correction
  1.040  MATH         APPEND(@CorrectionFile,S[1]&S[2])

# Make sure that stopFreqGHz is included in the testing
  1.041  MATH         L[1] = @FreqGHz < stopFreqGHz
  1.042  MATH         L[2] = @FreqGHz + stepFreqGHz > stopFreqGHz

  1.043  IF           L[1] && L[2]
  1.044  MATH         @FreqGHz = stopFreqGHz
  1.045  ELSE
  1.046  MATH         @FreqGHz = @FreqGHz + stepFreqGHz
  1.047  ENDIF

  1.048  ENDW

  1.049  TARGET       -p

# Store the corrections into the DUT
  1.050  CALL         Sub MG369XC Store DC Pulse Corrections

  1.051  MATH         CLOSE(@CorrectionFile)

# End the calibration, save the results, and exit Cal mode.
  1.052  IEEE         WHX PGM [SRQ 5000] WH0
  1.053  WAIT         -a -t 15 Please wait for the unit to restart

  1.054  END
