﻿Anritsu                                                     MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Get Item Offset Value
DATE:                  2014-02-13 10:49:11
AUTHOR:                Al Shannon
REVISION:              $Revision: 8106 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       162
=============================================================================
#
#  Text Source:
#    $RCSfile: sub_mg369xc_get_item_offset_value.mc $
#    $Date: 2014-06-10 07:17:23 -0700 (Tue, 10 Jun 2014) $
#
#  Procedure Author:
#        AWS
#
#  Model(s) Covered:
#        MG369XC
#
#  Compatibility:
#        MET/CAL 8.0 or later
#
#  Input:
#        @Offset_FreqGHz   This is current test frequency
#        @Connection_Item  This is the item that is part of the connection
#
#  Output:
#        @Connection_Item_Offset_Value
#
#  Subprocedures:
#
#  Required Files:
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# The output variable will first be deleted.  If a valid result is found the
# output variable will then be defined with the output value.  If no valid
# result can be found, the variable will remain undefined.  Any subsequent
# attemt to refer to that variable will fail indicating there is no valid
# value for it.
  1.001  MATH         DEL("@Connection_Item_Offset_Value")

  1.002  IF           ZCMPI(@Connection_Item, "Anritsu 41KC-10")
  1.003  MATH         ModelNumber = "41KC-10"; File = "41KC-10.txt"
  1.004  ELSEIF       ZCMPI(@Connection_Item, "Anritsu 41V-10")
  1.005  MATH         ModelNumber = "41V-10"; File = "41V-10.txt"
  1.006  ELSE
  1.007  MATH         ModelNumber = @Connection_Item
  1.008  MATH         File = @Connection_Item & ".txt"
  1.009  ENDIF

  1.010  MATH         UserCWD = INI("Startup", "user_cwd")
  1.011  MATH         Path = UserCWD & "\\" & File

  1.012  MATH         AssetNumber  = ASSET(@Connection_Item)
  1.013  MATH         SerialNumber = SN(AssetNumber)
  1.014  MATH         LastCalDate  = CAL(AssetNumber, -1, 2301)

  1.015  MATH         LineNum = 1; First = 1; Offset = 0; @Error = 0

# Find item model.
  1.016  DO
  1.017  MATH         Line = READ(Path, LineNum); LineNum = LineNum + 1
  1.018  MATH         L[1] = ZCMPI(FLD(Line, 1, ":"), "ModelNumber")
  1.019  MATH         L[2] = FIND(FLD(Line, 2, ":"), ModelNumber, 1)

  1.020  IF           L[1] && L[2]

# Get serial number.
  1.021  DO
  1.022  MATH         Line = READ(Path, LineNum); LineNum = LineNum + 1
  1.023  MATH         L[1] = ZCMPI(FLD(Line, 1, ":"), "SerialNumber")
  1.024  MATH         L[2] = ZCMPI(STRIP(FLD(Line, 2, ":")), SerialNumber)

  1.025  IF           L[1] && L[2]

# Get calibration date.
  1.026  DO
  1.027  MATH         Line = READ(Path, LineNum); LineNum = LineNum + 1
  1.028  MATH         L[1] = ZCMPI(FLD(Line, 1, ":"), "CalDate")
  1.029  MATH         L[2] = ZCMPI(STRIP(FLD(Line, 2, ":")), LastCalDate)

  1.030  IF           L[1] && NOT(L[2])
  1.031  DISP         CalDate in file:
  1.031  DISP         [32] [V Path]
  1.031  DISP         is not the same as the last cal date for asset:
  1.031  DISP         [32] [V AssetNumber]
  1.031  DISP         Make sure the data in the file is up to date,
  1.031  DISP         and update CalDate line appropriately.
  1.032  MATH         @Error = 1
  1.033  END
  1.034  ENDIF

# Determine offset value.
  1.035  DO
  1.036  MATH         Line = READ(Path, LineNum); LineNum = LineNum + 1
  1.037  MATH         X2 = STRIPL(FLD(Line, 1, ","))
  1.038  MATH         Y2 = STRIPL(FLD(Line, 2, ","))

  1.039  IF           NOT(IS_NUM_LEAD(X2))
  1.040  DISP         Offset value cannot be determined for the following:
  1.040  DISP         [32] File:  [V Path]
  1.040  DISP         [32] Model: [V ModelNumber]
  1.040  DISP         [32] S/N:   [V SerialNumber]
  1.040  DISP         [32] Freq:  [V @Offset_FreqGHz] GHz
  1.041  MATH         @Error = 1
  1.042  END
  1.043  ENDIF

  1.044  IF           X2 == @Offset_FreqGHz
  1.045  MATH         @Connection_Item_Offset_Value = Y2
  1.046  END

  1.047  ELSEIF       First && (X2 > @Offset_FreqGHz)
  1.048  DISP         Offset value cannot be determined for the following:
  1.048  DISP         [32] File:  [V Path]
  1.048  DISP         [32] Model: [V ModelNumber]
  1.048  DISP         [32] S/N:   [V SerialNumber]
  1.048  DISP         [32] Freq:  [V @Offset_FreqGHz] GHz
  1.048  DISP
  1.048  DISP         Offset value can not be extrapolated below
  1.048  DISP         [V X2] GHz
  1.049  MATH         @Error = 1
  1.050  END

  1.051  ELSEIF       NOT(First) && (X2 > @Offset_FreqGHz)
  1.052  MATH         Offset = INTERP(X1, Y1, X2, Y2, @Offset_FreqGHz)
  1.053  MATH         @Connection_Item_Offset_Value = Offset
  1.054  END

  1.055  ELSE
  1.056  MATH         X1 = X2; Y1 = Y2
  1.057  ENDIF        ; X2 == @Offset_FreqGHz

  1.058  MATH         First = 0
  1.059  UNTIL        EOF(Path)

  1.060  UNTIL        EOF(Path)

  1.061  ENDIF

  1.062  UNTIL        EOF(Path)

  1.063  ENDIF

  1.064  UNTIL        EOF(Path)

  1.065  DISP         Offset value cannot be determined for the following:
  1.065  DISP         [32] File:  [V Path]
  1.065  DISP         [32] Model: [V ModelNumber]
  1.065  DISP         [32] S/N:   [V SerialNumber]
  1.065  DISP         [32] Freq:  [V @Offset_FreqGHz] GHz
  1.066  MATH         @Error = 1

  1.067  END
