﻿Anritsu                                                     MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XC Level Adj Connection /N5531S
DATE:                  2014-02-25 15:15:40
AUTHOR:                Fluke
REVISION:              $Revision: 8099 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       260
CONFIGURATION:         Agilent PSA (233)
CONFIGURATION:         Agilent EPM
CONFIGURATION:         Agilent N5532A-504
CONFIGURATION:         Agilent N5532A-550
=============================================================================
#
#  Text Source:
#    $RCSfile: sub_mg369xc_level_adj_connection_n5531s.mc $
#    $Date: 2014-06-10 06:40:19 -0700 (Tue, 10 Jun 2014) $
#
#  Procedure Author:
#        DAC, AWS
#
#  Model(s) Covered:
#        MG369XC
#
#  Compatibility:
#        MET/CAL 8.0 or later
#
#  Subprocedures:
#        Sub MG369XC Get Cal Power Sensor /N5532
#        Sub N5531S Get Power Sensor Model
#        Sub N5532 Power Sensor Get Series
#        Sub N5532 Power Sensor Get Connector Type
#        Sub N5532 Power Sensor Get Frequency Type
#        Sub N5532 Power Sensor Get Frequency Range
#        Sub N5532 Power Sensor Get Dynamic Range
#        Sub Audible Prompt
#        Sub MG369XC Init Connection Flags
#
#  Required Files:
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           ISVAR("@PS")
  1.002  MATH         CurrentPS = @PS
  1.003  ELSE
  1.004  MATH         CurrentPS = ""
  1.005  ENDIF

  1.006  TARGET       -p

# Get specified power sensor model based on freq and connection type.
  1.007  CALL         Sub MG369XC Get Cal Power Sensor /N5532

# See if power sensor has changed, turn off source RF and set variables
# to inital values.
  1.008  IF           NOT(ZCMP(CurrentPS, @PS))
  1.009  MATH         Sensor_Change = 1
  1.010  MATH         Do_Recal = 1
  1.011  ELSE
  1.012  MATH         Sensor_Change = 0
  1.013  MATH         Do_Recal = 0
  1.014  ENDIF

# If power sensor should change, get the characteristics of the power
# sensor that is needed and determine whether the new power sensor will
# be OK.
  1.015  IF           Sensor_Change
  1.016  CALL         Sub N5532 Power Sensor Get Series
  1.017  CALL         Sub N5532 Power Sensor Get Connector Type
  1.018  CALL         Sub N5532 Power Sensor Get Frequency Type
  1.019  CALL         Sub N5532 Power Sensor Get Frequency Range
  1.020  CALL         Sub N5532 Power Sensor Get Dynamic Range
  1.021  ENDIF

# Determine if power sensor can measure minimum and maximum level.
  1.022  IF           Sensor_Change
  1.023  IF           (@LvldBm < @PS_MinLvl) || (@LvldBm > @PS_MaxLvl)
  1.024  DISP         [V @LvldBm] dBm is outside [V @PS] range:
  1.024  DISP         [32] [V @PS_MinLvl] dBm to [V @PS_MaxLvl] dBm
  1.024  DISP
  1.025  END
  1.026  ENDIF        ; (@LvldBm < @PS_MinLvl) || (@LvldBm > @PS_MaxLvl)
  1.027  ENDIF        ; Sensor_Change

# Determine if power sensor can measure the frequnecy.
  1.028  IF           Sensor_Change
  1.029  MATH         Freq = @FreqGHz * 1E+9

  1.030  IF           (Freq < @PS_MinFreq) || (Freq > @PS_MaxFreq)
  1.031  MATH         Freq = ENGR_NSD(Freq, "Hz", 3)
  1.032  MATH         PS_MinFreq = ENGR_NSD(@PS_MinFreq, "Hz", 3)
  1.033  MATH         PS_MaxFreq = ENGR_NSD(@PS_MaxFreq, "Hz", 3)
  1.034  DISP         [V Freq] is outside [V @PS] range:
  1.034  DISP         [32] [V PS_MinFreq] to [V PS_MaxFreq]
  1.034  DISP
  1.035  END
  1.036  ENDIF        ; (Freq < @PS_MinFreq) || (Freq > @PS_MaxFreq)

  1.037  ENDIF        ; Sensor_Change

  1.038  IF           Do_Recal
# Put N5531S into measurement receiver mode so that the power meter can
# be controlled.  Put it in frequency counter mode.  If in RF Power mode
# it complains if the existing sensor is disconnected or not in cal.
  1.039  IEEE         [@N5531S][T30000]:INST MRECEIVE;:CONF:FCO
  1.040  CALL         Sub Audible Prompt
  1.041  DISP         Connect:
  1.041  DISP         [32][V @PS] to N1912A Sensor A and E4448A Input.
  1.041  DISP         [32]E4448A 10 MHz Out (Switched) to DUT 10 MHz Ref In.

  1.042  IF           ZCMP(@PS, "N5532A-504")
  1.043  IEEE2        [@N5531S]:MMEMory:LOAD:PSCFactor 'C:\504CFD.XML'
  1.044  N5531        Connect; Input = RF
  1.044  N5531        SensorModule = N5532A-504

  1.045  ELSEIF       ZCMP(@PS, "N5532A-550")
  1.046  IEEE2        [@N5531S]:MMEMory:LOAD:PSCFactor 'C:\550CFD.XML'
  1.047  N5531        Connect; Input = RF
  1.047  N5531        SensorModule = N5532A-550
  1.048  ENDIF        ; ZCMP(@PS, "N5532A-504") or ZCMP(@PS, "N5532A-550")

  1.049  CALL         Sub Audible Prompt

# This causes the user to connect the power sensor to calibrator and
# then runs the Zero Cal on the power meter.

  1.050  IF           ZCMP(@PS_Con, "N")
  1.051  DISP         Connect [V @PS] to N1912A CALIBRATOR output.
  1.052  ELSEIF       ZCMP(@PS_Con, "2.4 mm")
  1.053  DISP         Connect [V @PS] to CALIBRATOR output using a
  1.053  DISP         Type N (m) to Type 2.4 mm (f) adapter,
  1.053  DISP         Agilent P/N 11903-60002.
  1.054  ENDIF        ; ZCMP(@PS_Con, "N")

# The N5531 statement times out.  Use the native command.
  1.055  IEEE2        [@N5531S][T60000]:CAL:PMET:ZCAL

# Set the center freq of the N5531S to the desired freq so that the
# N5531S will not complain that the freq doesn't match the range covered
# by the new power sensor.  Use IEEE FSC so Met/Cal won't check for errors
# generated when the sensor changes.  Finally, clear any errors queued
# while changing sensors.
  1.056  IEEE         [@N5531S]:sens:freq:cent [V @FreqGHz] GHz;*cls

  1.057  ENDIF        ; Do_Recal


# Determine required connection.
  1.058  IF           NOT(ISVAR("@ConnPadValue"))
  1.059  MATH         @ConnPadValue = 0
  1.060  ENDIF

  1.061  IF           @ConnPadValue == 0

# N5532A/B-504
  1.062  IF           ZCMP(@PS, "N5532A-504")

  1.063  IF           ZCMP(@MG369XC_Con, "K")
  1.064  MATH         ReqCon = "MG369XC_N1912A_N5532A-504_N_K"

  1.065  ELSEIF       ZCMP(@MG369XC_Con, "V")
  1.066  MATH         ReqCon = "MG369XC_N1912A_N5532A-504_N_K_V"

  1.067  ENDIF        ; ZCMP(@MG369XC_Con, "K")

# N5532A/B-550
  1.068  ELSEIF       ZCMP(@PS_FreqType, "N5532A-550")

  1.069  IF           ZCMP(@MG369XC_Con, "K")
  1.070  MATH         ReqCon = "MG369XC_N1912A_N5532A-550_2.4_K"

  1.071  ELSEIF       ZCMP(@MG369XC_Con, "V")
  1.072  MATH         ReqCon = "MG369XC_N1912A_N5532A-550_2.4_V"

  1.073  ENDIF        ; ZCMP(@MG369XC_Con, "K")

  1.074  ELSE
  1.075  DISP         No connection picture available for [V @PS].
  1.076  END
  1.077  ENDIF

  1.078  ELSEIF       @ConnPadValue == 10

# N5532A/B-504
  1.079  IF           ZCMP(@PS, "N5532A-504")

  1.080  IF           ZCMP(@MG369XC_Con, "K")
  1.081  MATH         ReqCon = "MG369XC_N1912A_N5532A-504_N_K_10dB"

  1.082  ELSEIF       ZCMP(@MG369XC_Con, "V")
  1.083  MATH         ReqCon = "MG369XC_N1912A_N5532A-504_N_K_V_10dB"

  1.084  ENDIF        ; ZCMP(@MG369XC_Con, "K")

# N5532A/B-550
  1.085  ELSEIF       ZCMP(@PS_FreqType, "N5532A-550")

  1.086  IF           ZCMP(@MG369XC_Con, "K")
  1.087  MATH         ReqCon = "MG369XC_N1912A_N5532A-550_2.4_K_10dB"

  1.088  ELSEIF       ZCMP(@MG369XC_Con, "V")
  1.089  MATH         ReqCon = "MG369XC_N1912A_N5532A-550_2.4_V_10dB"

  1.090  ENDIF        ; ZCMP(@MG369XC_Con, "K")

  1.091  ELSE
  1.092  DISP         No connection picture available for [V @PS].
  1.093  END
  1.094  ENDIF

  1.095  ELSE
  1.096  DISP         Invalid connection pad value: [V @ConnPadValue]
  1.097  END
  1.098  ENDIF

# See if connection requirements have changed.
  1.099  IF           NOT(ZCMP(@MG369XC_N5532A_Con, ReqCon))
  1.100  IEEE         RF0
  1.101  CALL         Sub Audible Prompt

  1.102  IF           ZCMP(ReqCon, "MG369XC_N1912A_N5532A-504_N_K")
  1.103  PIC          MG369XC_N1912A_N5532-504_N_K
  1.104  MATH         @Connection_Type = "PS_504_to_K"
  1.105  ELSEIF       ZCMP(ReqCon, "MG369XC_N1912A_N5532A-550_2.4_K")
  1.106  PIC          MG369XC_N1912A_N5532-550_2_4K
  1.107  MATH         @Connection_Type = "PS_550_to_K"
  1.108  ELSEIF       ZCMP(ReqCon, "MG369XC_N1912A_N5532A-504_N_K_V")
  1.109  PIC          MG369XC_N1912A_N5532-504_NKV
  1.110  MATH         @Connection_Type = "PS_504_to_V"
  1.111  ELSEIF       ZCMP(ReqCon, "MG369XC_N1912A_N5532A-550_2.4_V")
  1.112  PIC          MG369XC_N1912A_N5532-550_2_4V
  1.113  MATH         @Connection_Type = "PS_550_to_V"
  1.114  ELSEIF       ZCMP(ReqCon, "MG369XC_N1912A_N5532A-504_N_K_10dB")
  1.115  PIC          MG369XC_N5532-504_N_K_10dB
  1.116  MATH         @Connection_Type = "PS_504_to_K_10dB"
  1.117  ELSEIF       ZCMP(ReqCon, "MG369XC_N1912A_N5532A-550_2.4_K_10dB")
  1.118  PIC          MG369XC_N5532-550_2_4K_10dB
  1.119  MATH         @Connection_Type = "PS_550_to_K_10dB"
  1.120  ELSEIF       ZCMP(ReqCon, "MG369XC_N1912A_N5532A-504_N_K_V_10dB")
  1.121  PIC          MG369XC_N5532-504_NKV_10dB
  1.122  MATH         @Connection_Type = "PS_504_to_V_10dB"
  1.123  ELSEIF       ZCMP(ReqCon, "MG369XC_N1912A_N5532A-550_2.4_V_10dB")
  1.124  PIC          MG369XC_N5532-550_2_4V_10dB
  1.125  MATH         @Connection_Type = "PS_550_to_V_10dB"
  1.126  ELSE
  1.127  DISP         No connection picture available for [V @PS].
  1.128  END
  1.129  ENDIF

  1.130  CALL         Sub MG369XC Init Level Adj Connection Flags
  1.131  MATH         @MG369XC_N5532A_Con = ReqCon
  1.132  ENDIF        ; NOT(ZCMP(@MG369XC_N5532A_Con, ReqCon))

  1.133  END
