﻿Anritsu                                                     MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XC Init Set Level DAC /N5531S
INSTRUMENT:            Sub MG369XC Set Level DAC /N5531S
DATE:                  2014-03-01 10:57:54
AUTHOR:                Al Shannon
REVISION:              $Revision: 8105 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       3
NUMBER OF LINES:       173
CONFIGURATION:         Agilent PSA (233)
CONFIGURATION:         Agilent EPM
=============================================================================
#
#  Text Source:
#    $RCSfile: sub_mg369xc_set_level_dac_n5531s.mc $
#    $Date: 2014-06-10 06:43:12 -0700 (Tue, 10 Jun 2014) $
#
#  Procedure Author:
#        AWS
#
#  Model(s) Covered:
#        MG369XC
#
#  Compatibility:
#        MET/CAL 8.0 or later
#
#  Subprocedures:
#        Sub MG369XC Level Adj Connection /N5531S
#        Sub Get Offset Value
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Anritsu Company.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  MATH         maximumDACValue = 16383
  1.002  MATH         minimumDACValue = 0

# high and low are the highest and lowest untested DAC values
  1.003  MATH         high = maximumDACValue
  1.004  MATH         low = minimumDACValue

  1.005  JMPL         INIT           PSUBI("MG369XC Init")
  1.006  JMPL         SET            PSUBI("MG369XC Set")
  1.007  DISP         Subprocedure not found!
  1.008  END
  1.009  EVAL

#=====================Sub MG369XC Init Set Level DAC /N5531S=================
  2.001  LABEL        INIT
  2.002  MATH         @ConnPadValue = 10
  2.003  CALL         Sub MG369XC Level Adj Connection /N5531S

# Set up Tuned RF Level measurement mode.
# Set the signal generator to the high DAC value to make sure the N5531S gets
# enough power to perform a valid Range 1 Cal.
  2.004  IEEE         PAD[V high]X[D50]

  2.005  N5531        RefFreqOutput = 10 MHz
  2.005  N5531        Freq = [V @FreqGHz]GHz; SensorModule = Same
  2.005  N5531        +Level = [V @LvldBm]dBm; Setup
  2.006  IEEE2        [@N5531S]:sens:freq:cent [V @FreqGHz] ghz
  2.007  N5531        RefFreqOutput = 10 MHz
  2.007  N5531        Freq = [V @FreqGHz]GHz; SensorModule = Same
  2.007  N5531        +Level = [V @LvldBm]dBm; Read

# Determine the amount the adapters and pads affect the power measurement
  2.008  MATH         @Offset_FreqGHz = @FreqGHz
  2.009  CALL         Sub Get Offset Value

  2.010  MATH         @PrevDAC = high
  2.011  MATH         @PrevPower = MEM + @Offset_Value

  2.012  END

  2.013  EVAL

#===================== Sub MG369XC Set Level DAC /N5531S=====================
  3.001  LABEL        SET

# Set initial DAC value to 6250.  (6250 is just a reasonable guess.)
  3.002  MATH         @LevelDAC = 6250

  3.003  WHILE        1

# Program the level DAC to the current value
  3.004  IEEE         PAD[V @LevelDAC]x[D50]

# Measure the power at this DAC setting
  3.005  IEEE2        [@N5531S]:READ:TRFL?[I$]
  3.006  MATH         pwrLvl = FLD(MEM2,1,",")

# Account for the loss from the adapters and pads
  3.007  MATH         pwrLvl = pwrLvl + @Offset_Value

# Provide a little feedback to the operator
  3.008  MATH         S[1] = FMT(pwrLvl, "%8.3f")
  3.009  HEAD         -2Measured Power: [S1]  Target Power: [V @LvldBm]

# If the measured power is in a range on the measuring receiver that is not
# calibrated, as indicated by "uncal", then we cannot trust the measurement.
# Increase the DAC setting, staying at or below "high", to get a power
# measurement that is in a calibrated range. "high" and "low" are not changed
# because we don't have a valid measurement from which we can adjust "high"
# or "low".  Finally, if @LevelDAC is equal to "high" there are no more DAC
# values to try
  3.010  IEEE2        [@N5531S]:CALC:TRFL:UNC?[I]
  3.011  MATH         uncal = MEM

  3.012  IF           uncal && @LevelDAC < high
  3.013  MATH         @LevelDAC = CEIL((@LevelDAC + high) / 2)
  3.014  ELSE

# If the measured power is close enough, we're done.  Otherwise adjust "high"
# or "low" and continue the search.
  3.015  IF           ABS(@LvldBm - pwrLvl) < 0.01
  3.016  MATH         @PrevDAC = @LevelDAC
  3.017  MATH         @PrevPower = pwrLvl
  3.018  END
  3.019  ELSEIF       pwrLvl > @LvldBm
  3.020  MATH         high = @LevelDAC - 1
  3.021  ELSE
  3.022  MATH         low = @LevelDAC + 1
  3.023  ENDIF

# If high < low then there are no more DAC values to check.  This is a
# failure if the unit will not produce enough power to reach the level
# requested.  Otherwise, just return the current DAC value.
  3.024  IF           high < low

  3.025  IF           low > maximumDACValue
  3.026  MATH         S[1] = "Error: Couldn't achieve " & @LvldBm
  3.027  MATH         S[2] = "Power is " & pwrLvl & " dBm at DAC " & @LevelDAC
  3.028  RSLT         =[S1]
  3.029  RSLT         =[S2]
  3.030  DISP         [S1]
  3.030  DISP         [S2]
  3.030  DISP         Abort the calibration!
  3.031  ENDIF

  3.032  MATH         @PrevDAC = @LevelDAC
  3.033  MATH         @PrevPower = pwrLvl
  3.034  END
  3.035  ENDIF

  3.036  MATH         L[1] = @PrevPower - pwrLvl
  3.037  MATH         L[2] = @PrevDAC - @LevelDAC
  3.038  MATH         L[3] = @LvldBm - pwrLvl

  3.039  MATH         @PrevDAC = @LevelDAC
  3.040  MATH         @PrevPower = pwrLvl

# Avoid divide by zero
  3.041  IF           (ABS(L[1]) >= 0.1) && (L[2] != 0)
  3.042  MATH         @LevelDAC = @LevelDAC + INT(L[3] * L[2] / L[1])

# Make sure @LevelDAC is in the interval high to low
  3.043  MATH         @LevelDAC = MIN2(@LevelDAC, high)
  3.044  MATH         @LevelDAC = MAX2(@LevelDAC, low)
  3.045  ELSE
  3.046  MATH         @LevelDAC = INT((high + low) / 2)
  3.047  ENDIF

  3.048  ENDIF        ; if uncal
  3.049  ENDW

  3.050  END
